@@ -25,7 +25,8 @@ pub enum Action {
     pagination: Pagination,
   },
   ListWorker {
-    //todo : ADD FILTERS !
+    identifier: Option<String>,
+    job_id: Option<String>,
     pagination: Pagination,
   },
   ListWorkflow {
@@ -92,12 +93,23 @@ impl Action {
         format!("/users?page={}&size={}", pagination.page, pagination.size)
       }
 
-      Action::ListWorker { pagination } => {
+      Action::ListWorker {
+        identifier,
+        job_id,
+        pagination,
+      } => {
         let base_url = "/step_flow/workers".to_string();
-        let url_options = vec![
+        let mut url_options = vec![
           format!("page={}", pagination.page),
           format!("size={}", pagination.size),
         ];
+        if let Some(single_instance_id) = identifier {
+          url_options.push(format!("instance_id={}", single_instance_id))
+        }
+
+        if let Some(single_job_id) = job_id {
+          url_options.push(format!("job_id={}", single_job_id))
+        }
         format!("{}?{}", base_url, url_options.join("&"))
       }
 
