@@ -1,15 +1,15 @@
-use mcai_models::{Workflow, WorkflowDuration};
+use mcai_models::{WorkflowDuration, WorkflowInstance};
 use serde::{Deserialize, Serialize};
 
 #[derive(Deserialize)]
 pub struct WorkflowList {
-  pub data: Vec<Workflow>,
+  pub data: Vec<WorkflowInstance>,
   pub total: usize,
 }
 
 #[derive(Deserialize, Serialize)]
 pub struct WorkflowShow {
-  pub data: Workflow,
+  pub data: WorkflowInstance,
 }
 
 #[derive(Debug, Deserialize, Serialize)]
